==> Scientific.0.8.9.tar.gz: FBEnterprise.framework/Versions/A/Headers/FBDisplayGroup.h <==
/* FBDisplayGroup.h created by ahoesch on Wed 13-Dec-2000 */

#import <Foundation/Foundation.h>
//#import "FBObserving.h"
#import "FBDelayedObserver.h"

@class FBDataSource;
@class FBQualifier;
@class FBObject;
@class FBGlobalID;
@class FBEditingContext;

#define FBDisplayGroupSelectionDidChangeNotification @"FBDisplayGroupSelectionDidChangeNotification"
#define FBDisplayGroupSubjectChangedNotification @"FBDisplayGroupSubjectChangedNotification"

enum { DisplayGroupSelectionChange = 1, DisplayGroupSelectedObjectChange = 2, DisplayGroupObjectArrayChange = 4 };
   
//@interface FBDisplayGroup : NSObject <FBObserving>
@interface FBDisplayGroup : FBDelayedObserver
{
   FBDataSource *_dataSource;
   NSMutableArray *_objects;
   NSMutableArray *_displayedObjects;
   NSArray *_sortOrderings;
   NSMutableArray *_selectionIndexes;
   FBQualifier *_qualifier;
   id _delegate;
   BOOL _fetchOnLoad;
   BOOL _observeObjects;
   BOOL _autoSelect;
}

+ (id)createDisplayGroupForEntityNamed:(NSString *)entityName editingContext:(FBEditingContext *)editingContext;
+ (id)createDisplayGroupForParentDisplayGroup:(FBDisplayGroup *)parentDisplaygroup detailKey:(NSString *)detailKey;

- (void)setDataSource:(FBDataSource *)dataSource;
- (FBDataSource *)dataSource;

- (void)createDatabaseDataSourceWithEditingContext:(FBEditingContext *)editingContext;

- (void)setDelegate:(id)delegate;
- (id)delegate;

- (void)setQualifier:(FBQualifier *)qualifier;
- (FBQualifier *)qualifier;

- (void)setObjectArray:(NSArray *)objects;
- (void)fetch;
- (BOOL)shouldChangeSelection;
- (void)validateSelection;

- (void)setSortOrderings:(NSArray *)array;

- (void)insert;
- (void)insertObject:(FBObject *)object;
- (void)insertObjects:(NSArray *)objects;
- (void)insertObjectAtIndex:(unsigned int)index;
- (void)insertObject:(id)object atIndex:(unsigned int)index;

- (void)delete;
- (void)deleteSelection;
- (void)deleteDisplayedObjectAtIndex:(unsigned int)index;

- (NSArray *)allObjects;
- (NSArray *)displayedObjects;
- (void)updateDisplayedObjects;

- (FBObject *)selectedObject;
- (NSArray *)selectedObjects;
- (int)numberOfSelectedObjects;
- (int)selectedIndex;
- (void)selectObjectWithGlobalID:(FBGlobalID *)globalID;
- (void)selectObject:(FBObject *)object;
- (void)selectObjects:(NSArray *)objects;
- (BOOL)selectNext;
- (BOOL)selectPrevious;
- (BOOL)selectObjectAtIndex:(int)index;
- (BOOL)clearSelection;
- (BOOL)setSelectionIndexes:(NSArray *)indexes;
- (NSArray *)selectionIndexes;

- (int)numberOfDisplayedObjects;
- (FBObject *)displayedObjectAtIndex:(unsigned int)index;

- (BOOL)setSelectedObjectValue:(id)value forKey:(NSString *)key;
- (id)selectedObjectValueForKey:(NSString *)key;

- (void)postSelectionDidChangeNotification;
- (BOOL)clearSelection;

- (void)setFetchOnLoad:(BOOL)flag;
- (BOOL)fetchOnLoad;

- (void)setObserveObjects:(BOOL)flag;
- (BOOL)observeObjects;

- (void)setAutoSelect:(BOOL)flag;
- (BOOL)autoSelect;

- (BOOL)isInsertEnabled;
- (BOOL)isDeleteEnabled;
- (BOOL)checkInsertPrivilege;
- (BOOL)checkDeletePrivilege;
- (BOOL)checkDeletePrivilegeForObjects:(NSArray *)objects;

- (void)editingContextDidDeleteObject:(FBObject *)object;

@end

==> Scientific.0.9.tar.gz: FBEnterprise.framework/Versions/A/Headers/FBDisplayGroup.h <==
/* FBDisplayGroup.h created by ahoesch on Wed 13-Dec-2000 */

#import <Foundation/Foundation.h>
//#import "FBObserving.h"
#import "FBDelayedObserver.h"

@class FBDataSource;
@class FBQualifier;
@class FBObject;
@class FBGlobalID;
@class FBEditingContext;

#define FBDisplayGroupSelectionDidChangeNotification @"FBDisplayGroupSelectionDidChangeNotification"
#define FBDisplayGroupSubjectChangedNotification @"FBDisplayGroupSubjectChangedNotification"

enum { DisplayGroupSelectionChange = 1, DisplayGroupObjectChange = 2, DisplayGroupObjectArrayChange = 4 };
   
@interface FBDisplayGroup : FBDelayedObserver
{
   FBDataSource *_dataSource;
   NSMutableArray *_objects;
   NSMutableArray *_displayedObjects;
   NSArray *_sortOrderings;
   NSMutableArray *_selectionIndexes;
   FBQualifier *_qualifier;
   id _delegate;
   BOOL _fetchOnLoad;
   BOOL _observeObjects;
   BOOL _autoSelect;
}

+ (id)createDisplayGroupForEntityNamed:(NSString *)entityName editingContext:(FBEditingContext *)editingContext;
+ (id)createDisplayGroupForParentDisplayGroup:(FBDisplayGroup *)parentDisplaygroup detailKey:(NSString *)detailKey;

- (void)setDataSource:(FBDataSource *)dataSource;
- (FBDataSource *)dataSource;

- (void)createDatabaseDataSourceWithEditingContext:(FBEditingContext *)editingContext;

- (void)setDelegate:(id)delegate;
- (id)delegate;

- (void)setQualifier:(FBQualifier *)qualifier;
- (FBQualifier *)qualifier;

- (void)setObjectArray:(NSArray *)objects;
- (void)fetch;
- (BOOL)shouldChangeSelection;
- (void)validateSelection;

- (void)setSortOrderings:(NSArray *)array;

- (void)insert;
- (void)insertObject:(FBObject *)object;
- (void)insertObjects:(NSArray *)objects;
- (void)insertObjectAtIndex:(unsigned int)index;
- (void)insertObject:(id)object atIndex:(unsigned int)index;

- (void)delete;
- (void)deleteSelection;
- (void)deleteDisplayedObjectAtIndex:(unsigned int)index;

- (NSArray *)allObjects;
- (NSArray *)displayedObjects;
- (void)updateDisplayedObjects;

- (FBObject *)selectedObject;
- (NSArray *)selectedObjects;
- (int)numberOfSelectedObjects;
- (void)setSelectedIndex:(int)index;
- (int)selectedIndex;
- (void)selectObjectWithGlobalID:(FBGlobalID *)globalID;
- (void)selectObject:(FBObject *)object;
- (void)selectObjects:(NSArray *)objects;
- (BOOL)selectNext;
- (BOOL)selectPrevious;
- (BOOL)selectObjectAtIndex:(int)index;
- (BOOL)clearSelection;
- (BOOL)setSelectionIndexes:(NSArray *)indexes;
- (NSArray *)selectionIndexes;

- (int)numberOfDisplayedObjects;
- (FBObject *)displayedObjectAtIndex:(unsigned int)index;

- (BOOL)setSelectedObjectValue:(id)value forKey:(NSString *)key;
- (id)selectedObjectValueForKey:(NSString *)key;

- (BOOL)clearSelection;

- (void)setFetchOnLoad:(BOOL)flag;
- (BOOL)fetchOnLoad;

- (void)setObserveObjects:(BOOL)flag;
- (BOOL)observeObjects;

- (void)setAutoSelect:(BOOL)flag;
- (BOOL)autoSelect;

- (BOOL)isInsertEnabled;
- (BOOL)isDeleteEnabled;
- (BOOL)checkInsertPrivilege;
- (BOOL)checkDeletePrivilege;
- (BOOL)checkDeletePrivilegeForObjects:(NSArray *)objects;

- (void)editingContextDidDeleteObject:(FBObject *)object;

- (void)postSelectionDidChangeNotification;

@end
